@@ -4,7 +4,7 @@
 .gof.default <- function(object,...) {
   classes <- setdiff(gsub(pattern="^gof.",replacement="",as.vector(methods("gof"))), "default")
   stop("Goodness-of-Fit methods have been implemented only for class(es) ",
-       .paste.and(paste('"',classes,'"',sep="")), " in the packages loaded.")
+       paste.and(paste('"',classes,'"',sep="")), " in the packages loaded.")
 }
 
 gof.ergmm <- function (object, ..., nsim=100,
